==> knative-model-6.3.1-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/CloudEventAttributesFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CloudEventAttributesFluentImpl<A extends CloudEventAttributesFluent<A>> extends BaseFluent<A> implements CloudEventAttributesFluent<A>{
  public CloudEventAttributesFluentImpl() {
  }
  public CloudEventAttributesFluentImpl(CloudEventAttributes instance) {
    this.withSource(instance.getSource()); 
    this.withType(instance.getType()); 
  }
  private String source;
  private String type;
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CloudEventAttributesFluentImpl that = (CloudEventAttributesFluentImpl) o;
    if (source != null ? !source.equals(that.source) :that.source != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(source,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/CloudEventAttributesFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CloudEventAttributesFluentImpl<A extends CloudEventAttributesFluent<A>> extends BaseFluent<A> implements CloudEventAttributesFluent<A>{
  public CloudEventAttributesFluentImpl() {
  }
  public CloudEventAttributesFluentImpl(CloudEventAttributes instance) {
    if (instance != null) {
      this.withSource(instance.getSource());
      this.withType(instance.getType());
    }
  }
  private String source;
  private String type;
  public String getSource() {
    return this.source;
  }
  public A withSource(String source) {
    this.source=source; return (A) this;
  }
  public Boolean hasSource() {
    return this.source != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CloudEventAttributesFluentImpl that = (CloudEventAttributesFluentImpl) o;
    if (!java.util.Objects.equals(source, that.source)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(source,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (source != null) { sb.append("source:"); sb.append(source + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}
